Pinguino IDE 12
===============

Install from PyPI
~~~~~~~~~~~~~~~~~

.. code:: shell

    pip install pinguino

Install from source code
~~~~~~~~~~~~~~~~~~~~~~~~

.. code:: shell

    git clone https://github.com/PinguinoIDE/pinguino-ide.git Pinguino12-dev
    cd Pinguino12-dev
    git checkout v12-dev
    mv ~/.pinguino ~/.pinguino.copy
    python post_install.py
    python pinguino.py


`Report Bugs <https://github.com/PinguinoIDE/pinguino-ide/issues>`__
